/*
 * This file: list_text_exp.cpp
 *
 * DO NOT MODIFY THIS FILE.
 */
#include <string>
#include "CLList.cpp"

using namespace std;
using namespace uprm_icom4035;


// Explicit binding of templates

template class cl_list_node<string>;

template class list<string>;

template class Iterator<string>;

// List of strings
template class CLList<string>;

// Iterator of strings
template class CLLIterator<string>;
